@@ -29,8 +29,19 @@ sub set_query {
   my $query = shift;
   if( ref( $query ) ne 'Search::Xapian::Query' ) {
     $query = Search::Xapian::Query->new( $query, @_ );
+    $self->set_query1( $query );
+    return;
+  }
+  my $nargs = scalar(@_);
+  if( $nargs > 1) {
+    Carp::carp( "USAGE: \$enquire->set_query(\$query) or \$enquire->set_query(\$query, \$length)" );
+    exit;
+  }
+  if( $nargs == 0 ) {
+    $self->set_query1( $query );
+  } else {
+    $self->set_query2( $query, shift );
   }
-  $self->set_query_object( $query );
 }
 
 sub matches {
@@ -46,9 +57,9 @@ sub get_matching_terms_begin {
     my $arg = shift;
     my $arg_class = ref( $arg );
     if( $arg_class eq 'Search::Xapian::MSetIterator' ) {
-      return $self->get_matching_terms_begin1($arg);
-    } else {
       return $self->get_matching_terms_begin2($arg);
+    } else {
+      return $self->get_matching_terms_begin1($arg);
     }
   }
   Carp::carp( "USAGE: \$enquire->get_matching_terms_begin(\$docid) or \$enquire->get_matching_terms_begin(\$msetiterator)" );
@@ -61,9 +72,9 @@ sub get_matching_terms_end {
     my $arg = shift;
     my $arg_class = ref( $arg );
     if( $arg_class eq 'Search::Xapian::MSetIterator' ) {
-      return $self->get_matching_terms_end1($arg);
-    } else {
       return $self->get_matching_terms_end2($arg);
+    } else {
+      return $self->get_matching_terms_end1($arg);
     }
   }
   Carp::carp( "USAGE: \$enquire->get_matching_terms_end(\$docid) or \$enquire->get_matching_terms_end(\$msetiterator)" );
